==> haskell-commonmark-extensions-0.2.5.5-47.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-extensions
version:              0.2.5.5
visibility:           public
id:                   commonmark-extensions-0.2.5.5-DwZ7ll7vAlW5lAUZnqjmju
key:                  commonmark-extensions-0.2.5.5-DwZ7ll7vAlW5lAUZnqjmju
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  b345b916612d97856d419661c14e2432
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Alerts
    Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.6.6/site-local/commonmark-extensions-0.2.5.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/commonmark-extensions-0.2.5.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/commonmark-extensions-0.2.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-extensions
hs-libraries:         HScommonmark-extensions-0.2.5.5-DwZ7ll7vAlW5lAUZnqjmju
depends:
    base-4.18.2.1 commonmark-0.2.6.1-AFyWZFKNc0cCLBasjsgiue
    containers-0.6.7 emojis-0.1.4.1-VOXDtaadLD4hNN8sCPzYl
    filepath-1.4.300.1 network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS
    parsec-3.1.16.1 text-2.0.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-extensions-0.2.5.5-48-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-extensions
version:              0.2.5.5
visibility:           public
id:                   commonmark-extensions-0.2.5.5-D3kq1Kzu7BvHjswrPw309p
key:                  commonmark-extensions-0.2.5.5-D3kq1Kzu7BvHjswrPw309p
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  b8e3cc32fd2372451e5cc518bca4ccd2
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Alerts
    Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.6.6/site-local/commonmark-extensions-0.2.5.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/commonmark-extensions-0.2.5.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/commonmark-extensions-0.2.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-extensions
hs-libraries:         HScommonmark-extensions-0.2.5.5-D3kq1Kzu7BvHjswrPw309p
depends:
    base-4.18.2.1 commonmark-0.2.6.1-GUdQFBTT0dEFTdPQeDlNIQ
    containers-0.6.7 emojis-0.1.4.1-L7mOnPsQOMB2xPGhke4egp
    filepath-1.4.300.1 network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI
    parsec-3.1.16.1 text-2.0.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
